@@ -4,31 +4,32 @@
 modname = 'timesheet'
 distname = 'cubicweb-%s' % modname
 
-numversion = (0, 2, 1)
+numversion = (0, 2, 2)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
-copyright = '''Copyright (c) 2008-2010 LOGILAB S.A. (Paris, FRANCE).
-http://www.logilab.fr/ -- mailto:contact@logilab.fr'''
-
+description = 'record who did what and when for the CubicWeb framework'
+web = 'http://www.cubicweb.org/project/%s' % distname
 author = 'Logilab'
 author_email = 'contact@logilab.fr'
 
-short_desc = 'timesheet component for the CubicWeb framework'
-long_desc = '''This CubicWeb component is for tracking resource availability
-and usage (persons and their daily activities, meeting rooms and their
-occupancy, etc.)
-.
-CubicWeb is a semantic web framework, see http://www.cubicweb.org
-'''
+
+
+classifiers = [
+           'Environment :: Web Environment',
+           'Framework :: CubicWeb',
+           'Programming Language :: Python',
+           'Programming Language :: JavaScript',
+           ]
+
+__depends__ = {'cubicweb': '>= 3.6.0',
+               'cubicweb-calendar':  '>= 0.1.0',
+               'cubicweb-workorder': '>= 0.6.0',
+               }
 
 from os import listdir as _listdir
 from os.path import join, isdir
 
-web = 'http://www.cubicweb.org/project/%s' % distname
-
-pyversions = ['2.4']
-
 #from cubicweb.devtools.pkginfo import get_distutils_datafiles
 CUBES_DIR = join('share', 'cubicweb', 'cubes')
 THIS_CUBE_DIR = join(CUBES_DIR, 'timesheet')
@@ -53,19 +54,3 @@ try:
 except OSError:
     # we are in an installed directory
     pass
-
-cube_eid = None # <=== FIXME if you need direct bug-subscription
-__depends_cubes__ = {'calendar':  '>= 0.1.0',
-                     'workorder': '>= 0.6.0',
-                     }
-__depends__ = {'cubicweb': '>= 3.6.0'}
-for key, value in __depends_cubes__.items():
-    __depends__['cubicweb-'+key] = value
-__use__ = tuple(__depends_cubes__)
-__recommend__ = ()
-classifiers = [
-           'Environment :: Web Environment',
-           'Framework :: CubicWeb',
-           'Programming Language :: Python',
-           'Programming Language :: JavaScript',
-           ]
