@@ -93,8 +93,10 @@ class MyActivities(startup.IndexView):
         #req.user.view('euser-activities-submitform', startup=True, w=self.w)
         # orders
         self.w(u'<h1>%s</h1>' % _('Open workorders'))
+        open_state = req.vreg['etypes'].etype_class('WorkOrder').open_state
         rset = req.execute('Any W,O ORDERBY T,TT WHERE O title T, O split_into W, '
-                           'W is WorkOrder, W title TT, W in_state S, S name "in progress"')
+                           'W is WorkOrder, W title TT, W in_state S, S name "%s"'
+                           % open_state)
         self.wview('progress_table_view', rset, 'null')
 
 
